<?php
 /**
** Adds logo_slider_widget widget.
**/
add_action('widgets_init', 'single_category_products_widget');
function single_category_products_widget() {
    /**
     * Check if WooCommerce is active
     **/
    if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
        return;
    }
    register_widget('ostore_single_category_products_widget_area');
}

class ostore_single_category_products_widget_area extends WP_Widget {

    /**
    * Register widget with WordPress.
    **/
    protected $kwidget; 
    public function __construct() {
        parent::__construct(
            'ostore_single_category_products_widget_area', 'OS: Single Category  Products', array(
            'description' => __('Display Single Category  Products Display', 'ostore')
        ));

        $this->kwidget = KWidget::get_instance();
    }
    
    /*
    * prepare fields array
    */
    private function widget_fields() {
        return array( 
			
			'single_category_collection' => array(
                'name' => 'single_category_collection',
                'title' => __('Select Single  Category Products', 'ostore'),
                'desc'  => __("Select Category", 'ostore'),
                'type'  => 'wocategory'
            ),
            'number_of_products' => array(
                'name' => 'number_of_products',
                'title' => __('Number of Products', 'ostore'),
                'desc'  => __("Select Category", 'ostore'),
                'type'  => 'number'
			)                
		);
    } 
    /**
    * Update Form Vlaue 
    */
    public function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $widget_fields = $this->widget_fields();
        foreach ($widget_fields as $widget_field) {
            extract($widget_field);
            $instance[$name] = $this->kwidget->update($widget_field, $new_instance[$name]);
        }
        return $instance;
    }

    /**
    * Backend Form 
    **/
    public function form($instance) {
        $widget_fields = $this->widget_fields();
        foreach ($widget_fields as $widget_field) {
            extract($widget_field);
            $widgets_field_value = !empty($instance[$name]) ? $instance[$name] : '';
            $this->kwidget->prepare($this, $widget_field, $widgets_field_value);
        }
    }

    /**
    * Display section(frontend)
    */
    public function widget($args, $instance) {
        extract($args);
        extract($instance);

        /**
        * wp query for first block
        **/  
        $single_category_collection_id = $instance['single_category_collection'];
        $number_of_products = $instance['number_of_products'];
        $categories_id = array();

        
        echo $before_widget; 
        ?>
        <section id="hot-deal" class="ostore-hot-deal">
        <div class="container">
            <?php 
            $term = get_term_by( 'id', intval($single_category_collection_id), 'product_cat');
            $hot_deal_title = $term->name;
            $hot_deal_short_desc = substr($term->description,0,40);
            ostore_title($hot_deal_title,$hot_deal_short_desc) ?>
                <?php
                    $product_args = array(
                        'post_type' => 'product',
                        'tax_query' => array(
                            array(
                                'taxonomy'  => 'product_cat',
                                'field'     => 'term_id', 
                                'terms'     => $single_category_collection_id                                                                 
                            )),
                        'posts_per_page' => $number_of_products
                    );
                    $query = new WP_Query($product_args);
                    if($query->have_posts()) { while($query->have_posts()) { $query->the_post();
                        ?>
                        <div class="col-md-3 col-sm-6 ostore-hot-deal">
            
                    <div <?php post_class('product-item product-hot-item'); ?> >
                        <div class="item-inner fadeInUp">
                            <div class="product-thumbnail">
                                <div class="icon-hot-label hot-right"><?php esc_html_e('Hot','ostore'); ?></div>
                                    <div class="pr-img-area">
                                    <figure>
                                        <a href="<?php the_permalink(); ?>">
                                        <?php echo get_the_post_thumbnail(get_the_ID(), 'shop_catalog', array( 'class' => 'first-img' ) ); ?> 
                                        </a>
                                    </figure>
                                    <button type="button" class="add-to-cart-mt"> <i class="fa fa-shopping-cart"></i><span><?php woocommerce_template_loop_add_to_cart(); ?> </span> </button>
                                </div>
                                <div class="pr-info-area">
                                    <div class="pr-button">
                                        <div class="mt-button add_to_wishlist-1">
                                            <?php if(function_exists( 'ostore_wishlist_products' )) { ostore_wishlist_products(); } ?> 
                                        </div>
                                        <div class="mt-button add_to_compare"> 
                                            <?php if(function_exists( 'ostore_add_compare_link' )) { ostore_add_compare_link(); } ?>                                   
                                        </div>
                                        <div class="mt-button quick-view"> 
                                            <?php if(function_exists( 'ostore_quickview' )) { ostore_quickview(); } ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="item-info">
                                <div class="info-inner">
                                <div class="item-title"> <a  href="<?php the_permalink(); ?>"><?php the_title(); ?></a> </div>
                                <div class="item-content">
                                <div class="rating">
                                        <span> <?php ostore_get_star_rating() ?> </span>  
                                    </div>
                                    <div class="item-price">
                                    <div class="price-box"> <span class="regular-price"> <span class="price"><?php woocommerce_template_loop_price(); ?></span> </span> </div>
                                    </div>
                                </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    </div>                        
                    <?php } }else{
                        echo esc_html_e("No products found!", 'ostore');
                    } wp_reset_postdata(); ?>
                </div>
            
            </section>
        <?php      
        echo $after_widget;
    }
}